| Title: | Interactive Directory Listing |
|---|---|
| Description: | A HTML widget for pretty directory listing with collapsible folders. |
| Authors: | Emi Tanaka [aut, cre, cph] (ORCID: <https://orcid.org/0000-0002-1455-259X>) |
| Maintainer: | Emi Tanaka <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 1.0.0 |
| Built: | 2026-07-05 08:33:46 UTC |
| Source: | https://github.com/emitanaka/dir |
Output and render functions for using dir within Shiny applications and interactive Rmd documents.
dirOutput(outputId, width = "100%", height = "400px") renderDir(expr, env = parent.frame(), quoted = FALSE)dirOutput(outputId, width = "100%", height = "400px") renderDir(expr, env = parent.frame(), quoted = FALSE)
outputId |
output variable to read from |
width, height
|
Must be a valid CSS unit (like |
expr |
An expression that generates a dir |
env |
The environment in which to evaluate |
quoted |
Is |
Create a HTML directory listing that is best used for R Markdown documents with HTML outputs, including for HTML presentations.
listing( path = ".", recurse = TRUE, show_hidden = FALSE, open = TRUE, width = NULL, height = NULL, elementId = NULL )listing( path = ".", recurse = TRUE, show_hidden = FALSE, open = TRUE, width = NULL, height = NULL, elementId = NULL )
path |
A path. |
recurse |
If |
|
If |
|
open |
Whether the folders should be open by default. |
width, height
|
Must be a valid CSS unit (like |
elementId |
The element ID. |
A list of files and folders.
## Not run: listing(system.file(package = "dir")) ## End(Not run)## Not run: listing(system.file(package = "dir")) ## End(Not run)